/*
 * 3D City Database - The Open Source CityGML Database
 * http://www.3dcitydb.org/
 *
 * Copyright 2013 - 2019
 * Chair of Geoinformatics
 * Technical University of Munich, Germany
 * https://www.gis.bgu.tum.de/
 *
 * The 3D City Database is jointly developed with the following
 * cooperation partners:
 *
 * virtualcitySYSTEMS GmbH, Berlin <http://www.virtualcitysystems.de/>
 * M.O.S.S. Computer Grafik Systeme GmbH, Taufkirchen <http://www.moss.de/>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.citydb.citygml.importer.database.xlink.importer;

import java.sql.PreparedStatement;
import java.sql.SQLException;

import org.citydb.citygml.common.cache.CacheTable;
import org.citydb.citygml.common.xlink.DBXlinkTextureAssociationTarget;

public class DBXlinkImporterTextureAssociationTarget implements DBXlinkImporter {
	private final DBXlinkImporterManager xlinkImporterManager;
	private PreparedStatement psXlink;
	private int batchCounter;

	public DBXlinkImporterTextureAssociationTarget(CacheTable tempTable, DBXlinkImporterManager xlinkImporterManager) throws SQLException {
		this.xlinkImporterManager = xlinkImporterManager;

		psXlink = tempTable.getConnection().prepareStatement("insert into " + tempTable.getTableName() + 
			" (SURFACE_DATA_ID, SURFACE_GEOMETRY_ID, GMLID) values " +
			"(?, ?, ?)");
	}

	public boolean insert(DBXlinkTextureAssociationTarget xlinkEntry) throws SQLException {
		psXlink.setLong(1, xlinkEntry.getSurfaceDataId());
		psXlink.setLong(2, xlinkEntry.getSurfaceGeometryId());
		psXlink.setString(3, xlinkEntry.getGmlId());

		psXlink.addBatch();
		if (++batchCounter == xlinkImporterManager.getCacheAdapter().getMaxBatchSize())
			executeBatch();

		return true;
	}

	@Override
	public void executeBatch() throws SQLException {
		psXlink.executeBatch();
		batchCounter = 0;
	}

	@Override
	public void close() throws SQLException {
		psXlink.close();
	}

	@Override
	public DBXlinkImporterEnum getDBXlinkImporterType() {
		return DBXlinkImporterEnum.TEXTUREASSOCIATION_TARGET;
	}

}
